
% user specified settings
num_slices = 50; % number of slices
num_volumes = 1; % number of time instances
num_labels = 5; % number of labels (foreground, background)
length_im = 100; % length of images
width_im = 100; % width of images
epsilon = 10^-3; % convergence threshold
save_output_ims = 0; % flag for determining whether or not to save the
                     % stapled images to the output directory.
view_output_ims = 0; % flag for determining whether or not to view the
                     % stapled images
bias = 1; % used when calculating theta
bias_factor = 0; % used when calculating theta
data_dir = 'data'; % directory containing data files
truth_dir = 'truth'; % directory containing truth files
st_slice = 1; % starting slice number in the data directory
st_slice_truth = 1; % starting slice number in the truth directory
file_reg_ex = '*.png'; % regular expression to catch all data images
out_dir = 'staple_estimates_consensus'; % output directory for the stapled estimates
ignore_file = 'ignore.txt'; % text file indicating which files to ignore
min_ratings = 0; % minimum number of ratings to count rater
ignore_raters = []; % list of raters to ignore

% some additional consensus model parameters
cval = 0.95;
pcon = [.9999 .0001];

% additional simulation settings
num_raters = 20; %20;
lower_lim_diag = 0.45;
upper_lim_diag = 0.65;
perc_confusion = [0.1];
length_im_confusion = round(sqrt(length_im * width_im * perc_confusion));
covs = 3:num_raters; %4:num_raters;
monte_carlo_runs = 10;

% allocate memory for the results
results = zeros(2, length(length_im_confusion), length(covs), monte_carlo_runs);
theta_results = cell(3, length(length_im_confusion), length(covs), ...
                     monte_carlo_runs);

% calculate some parameters
num_voxels_per_im = width_im * length_im; % number of voxels per slice
num_voxels = num_voxels_per_im * num_slices * num_volumes; % number of voxels
ignores = {}; %textread(ignore_file, '%s', 'delimiter', '\n');

for l = 1:length(length_im_confusion)
    % delete any leftover png files
    delete([data_dir, '/*.png']);
    delete([truth_dir, '/*.png']);

    % create the simulation files
    cms = create_consensus_simulation(data_dir, truth_dir, num_raters, ...
                                      num_slices, num_labels, length_im, ...
                                      length_im_confusion(l), ...
                                      lower_lim_diag, upper_lim_diag);
    pause();
    % gather all of the observations into the cell array
    obs = get_initial_obs(data_dir, file_reg_ex, ignores, num_voxels_per_im);

    % remove unwanted raters
    [obs ignore_raters] = rm_unwanted_raters(obs, ignore_raters, min_ratings);

    % get the rater list and the slice list for the observations
    [rater_list, slice_list] = get_obs_info(obs);

    % get an array of the truth
    truth = get_estimates(num_slices, st_slice_truth, num_voxels_per_im, ...
                          num_voxels, truth_dir);


    % run it for each number of coverages
    for c = 1:length(covs);

        % run the monte carlo simulation
        for i = 1:monte_carlo_runs

            % get a random fraction of pobs fraction of the total observation
            obsnew = get_coverage_obs(obs, covs(c));

            % run the staple consensus algorithm
            [new_truth_t theta_t W_t] = ...
                        STAPLE_consensus_theory(obsnew, num_slices, ...
                                                num_labels, ...
                                                num_voxels_per_im, ...
                                                num_voxels, bias, ...
                                                bias_factor, epsilon, cval, ...
                                                pcon, length_im, width_im);

            % run the staple algorithm (no bias)
            [new_truth_s theta_s W_s] = ...
                                         STAPLE(obsnew, num_slices, ...
                                                num_labels,...
                                                num_voxels_per_im, ...
                                                num_voxels, bias, ...
                                                bias_factor, epsilon);

            % calculate the results
            err_t = abs(double(new_truth_t) - double(truth));
            err_s = abs(double(new_truth_s) - double(truth));
            size_conf = num_slices * length_im_confusion(l)^2;
            results(1, l, c, i) = length(err_t(err_t ~= 0)) / (size_conf);
            results(2, l, c, i) = length(err_s(err_s ~= 0)) / (size_conf)

            theta_results{1, l, c, i} = theta_t;
            theta_results{2, l, c, i} = theta_s;
            theta_results{3, l, c, i} = cms(:, :, unique(obsnew.raters));
        end
    end
end

