function cms = create_consensus_simulation_biased(data_dir, truth_dir, num_raters, ...
                                     num_slices, num_labels, length_im, ...
                                     length_im_confusion, lower_lim_diag, ...
                                     upper_lim_diag)
% function that creates the simulated observations and truth images for the
% consensus STAPLE simulation

% initial settings
%data_dir = 'data';
%truth_dir = 'truth';
%num_raters = 20;
%num_slices = 50;
%num_labels = 3;
%length_im = 100;
%length_im_confusion = 20; %71;
%lower_lim_diag = 0.35;
%upper_lim_diag = 0.65;

%
% create the confusion matrices
%
diag_vals = linspace(lower_lim_diag, upper_lim_diag, num_raters);

% allocate space for the confusion matrices
cms = zeros([num_labels num_labels num_raters]);

% iterate over all of the raters
for i = 1:num_raters
    % set the diagonal values
    cm = diag(diag_vals(i) * ones([1 num_labels]));

    % fill in the off-diagonal values
    for j = 1:num_labels
        % generate (num_labels - 1) values to fill in the off-diagonals
        nums = rand([1 (num_labels-1)]);

        % calculate how much probability is available
        ava = 1 - diag_vals(i);

        % normalize these values so that we can just slap them into the cm
        nums = ava * (nums / sum(nums));

        count = 0;
        for k = 1:num_labels
            if (j ~= k)
                count = count + 1;
                cm(k, j) = nums(count);
            end
        end
    end
    cms(:,:,i) = cm;
end

% generate the initial truth images
truth = zeros([length_im length_im num_slices]);
x = round(linspace(0, length_im, num_labels));
for i = 1:num_slices
    label_perm = randperm(num_labels - 1);
    for j = 1:num_labels-1
        truth(:, x(j)+1:x(j+1), i) = label_perm(j);
    end
end

% create a section in the middle which is where all of the variation occurs
truth_section = zeros([length_im_confusion length_im_confusion]);

% create the section where the variation will be applied
%x = round(linspace(0, length_im_confusion, num_labels+1));
x = round(linspace(1, length_im_confusion+1, num_labels+1))-1;
for i = 1:num_labels
    truth_section(x(i)+1:x(i+1), :) = i-1;
end

% find where we want to place the truth_section in the truth images
bind_l = floor(length_im / 2) - floor(length_im_confusion / 2);
eind_l = bind_l + length_im_confusion - 1;
bind_w = floor(length_im / 2) - floor(length_im_confusion / 2);
eind_w = bind_w + length_im_confusion - 1;

% apply the truth section to each image
for i = 1:num_slices
    truth(bind_l:eind_l, bind_w:eind_w, i) = truth_section;
end

% create the user data
data = zeros(length_im, length_im, num_slices, num_raters);

% iterate over all raters
for r = 1:num_raters
    % iterate over all slices
    for s = 1:num_slices

        % apply the confusion matrix to the truth section
        obs_section = observeWithRandomRater(truth_section+1, ...
                                             squeeze(cms(:,:,r))) - 1;

        % apply the observed section to the truth data
        obs = squeeze(truth(:,:,s));
        obs(bind_l:eind_l, bind_w:eind_w) = obs_section;

        data(:,:,s,r) = obs;
    end
end

% the colormap for the output images
cmap = [1 1 1; 0 0 1; 0 1 0; 1 0 1; 1 0 0; 1 1 0];

% for some reason I have to do this to get the images to save properly
truth = uint8(truth);
data = uint8(data);

% save the truth estimates
for i = 1:num_slices
    fname_png = [truth_dir, '/truth_vol1_sl', sprintf('%02d', i), '.png'];
    imwrite(squeeze(truth(:,:,i)), cmap, fname_png, 'png');
end

% save the data observations
for s = 1:num_slices
    for r = 1:num_raters
        fname_png = [data_dir, '/obs_rater', sprintf('%02d', r), '_vol1_sl', ...
                     sprintf('%02d', s), '.png'];
        imwrite(squeeze(data(:,:,s,r)), cmap, fname_png, 'png');
    end
end


%consensus = zeros(length_im, length_im);
%consensus(bind_l:eind_l, bind_w:eind_w) = 1;
%figure(1); clf; imagesc(consensus); colormap([0 0 0; 1 1 1]);
%figure(2); clf; imagesc(cms(:,:,1)); colormap(jet); caxis([0 1]); colorbar;
%set(gca, 'XTick', 1:3);
%set(gca, 'YTick', 1:3);
%set(gca, 'XTickLabel', {'1', '2', '3'});
%set(gca, 'YTickLabel', {'1', '2', '3'});
%pause();
%cmap2 = [0 0 0; 1 1 1];
%imwrite(uint8(consensus), cmap2, 'consensus.png', 'png');
%imwrite(255*cms(:, :, 1), jet, 'confusion-matrix.png', 'png');

