function obs = observeWithRandomRater(truthLabel,confusionMatrix)
% TruthLabel = N-D integers 1...L
% confusionMatrix = L x L matrix with p(report label = i | true label = j)
% = confusionMatrix(i,j)
%
%% Example:
% tr = 1+round(rand([10 10 10])*7);
% cm = 10*diag(ones([8 1]))+rand([8 8]); cm = cm./repmat(sum(cm,1),[8 1]);
% obs = observeWithRandomRater(tr,cm);
%
%% Example 2 (verify): 
% tr = ones([100 100 100]);
% cm = 10*diag(ones([8 1]))+rand([8 8]); cm = cm./repmat(sum(cm,1),[8 1]);
% obs = observeWithRandomRater(tr,cm);
% for i=1:8, I(i)=mean(obs(:)==i); end
% disp('Compare L(specified)/R(realized):'); disp([cm(:,1) I'])
%
% Bennett Landman, bennett.landman@vanderbilt.edu
% March 9, 2010

% Step 1: Check inputs

if(min(truthLabel(:))<1)
    error('Minimum truth label must be >0');
end
L = size(confusionMatrix,1);
if(L~=size(confusionMatrix,2))
    error('Confusion Matrix must be square');
end
if(max(truthLabel(:))>L)
    error('Maximum label must be less than or equal to the size of the confusion matrix');
end

% Step 2: Create an random number for each vx uniform in [0 1]
vxRand = rand(size(truthLabel(:))); 

% Step 3: Generate a CDF for each voxel
confusionMatrixCDF = cumsum(confusionMatrix,1);
vxCMCDF = confusionMatrixCDF(:,truthLabel(:))';

% Step 4: Map Uniform distribution to discrete distribution
obs =reshape(1+sum(repmat(vxRand,[1 L])>vxCMCDF,2),size(truthLabel));