function theta = COLLATE_calc_theta_spatial(W, obs, upds, num_raters, dims,...
                                            bias, bias_factor, pcon)
% assumes that each rater (j) observed each slice exactly once

% number of labels and number of voxels comes from the size of W
num_labels = size(W, 4);
num_consensus_lvls = size(W, 5);

% initialize theta
theta = zeros([num_labels num_labels num_raters upds.num]);

%% Pre-init bias
%if bias == 1
%    bias_confusion = diag(ones([1 num_labels]));
%    for j = 1:num_raters
%        for u = 1:upds.num
%            theta(:, :, j, u) = bias_confusion * bias_factor * (prod(dims) ...
%                    / num_raters);
%        end
%    end
%    theta = theta + 0.001;
%end

for u = 1:upds.num

    % get the window corners
    xs = upds.startx(u);
    xe = upds.endx(u);
    ys = upds.starty(u);
    ye = upds.endy(u);
    zs = upds.startz(u);
    ze = upds.endz(u);

    % initialize lambda
    lambda = zeros(num_raters, num_labels);

    % construct both the lambda and theta values
    for j = 1:num_raters

        % iterate over every column in theta
        for s = 1:num_labels

            % calculate all of the factors necessary to
            % calculate lambda and theta
            Q = 0;
            W_p = [0 0];

            for m = zs:ze
                % calculate the Q parameter
                [snx sny] = find(obs.data{j}(xs:xe, ys:ye, m) ~= s-1);
                snx = snx + (xs - 1);
                sny = sny + (ys - 1);
                for n = 1:length(snx)
                    Q = Q + sum(W(snx(n), sny(n), m, s, :));
                end

                % calculate the W_p parameter
                [sx sy] = find(obs.data{j}(xs:xe, ys:ye, m) == s-1);
                sx = sx + (xs - 1);
                sy = sy + (ys - 1);
                for c = 1:num_consensus_lvls
                    for n = 1:length(sx)
                        W_p(c) = W_p(c) + sum(sum(W(sx(n), sy(n), m, s, c)));
                    end
                end
            end

            % calculate alpha
            alpha = 1;
            % calculate beta
            beta = Q + pcon(1)*W_p(1) + pcon(2)*W_p(2);
            % calculate gamma
            gamma = prod(pcon) * Q * (Q + W_p(1) + W_p(2));

            % calculate the value of lambda for 'j' rater and 's' label
            lambda(j, s) = (-beta - sqrt(beta^2 - 4 * alpha * gamma)) ...
                           / (2 * alpha);

            % calculate off-diagonal theta
            for l = 1:num_labels
                if (l ~= s)
                    for m = zs:ze
                        [sx sy] = find(obs.data{j}(xs:xe, ys:ye, m) == l-1);
                        sx = sx + (xs - 1);
                        sy = sy + (ys - 1);

                        for n = 1:length(sx)
                            theta(l, s, j, u) = theta(l, s, j, u) + ...
                                                sum(W(sx(n), sy(n), m, s, :));
                        end
                    end
                    theta(l, s, j, u) = theta(l, s, j, u) / (-lambda(j, s));
                end
            end

            % calculate on-diagonal theta
            a = prod(pcon) * lambda(j, s);
            b = sum(pcon.^2) * lambda(j, s) + prod(pcon) * (sum(W_p));
            c = a + (pcon(1)^2) * W_p(1) + (pcon(2)^2) * W_p(2);
            theta(s, s, j, u) = (-b - sqrt(b^2 - 4*a*c)) / (2*a);

            %if (theta(s, s, j, u) < 0)
            %    theta(s, s, j, u) = 100;
            %end

            if lambda(j, s) == 0
                theta(:, s, j, u) = 0;
                theta(s, s, j, u) = 1;
            end

            if length(find(isnan(theta)))
                keyboard;
            end

        end

        %% get rid of "perfect raters"
        %theta(:, :, j, u) = theta(:, :, j, u) + 0.001;
        %for k = 1:size(theta, 2)
        %    theta(:, k, j, u) = theta(:, k, j, u) / sum(theta(:, k, j, u));
        %end
    end
end

