function W = COLLATE_calc_w_spatial(theta, upds, num_raters, obs, dims, ...
                                    pcon, C, t_prior, c_prior)

% find the number of labels
num_labels = size(theta, 1);
% initialze W
W = ones(dims(1), dims(2), dims(3), num_labels, length(pcon));

%
% use the data adaptive prior
%
for s = 1:num_labels
    for c = 1:length(pcon)
        W(:, :, :, s, c) = W(:, :, :, s, c) * t_prior(s) * c_prior(c, s);
    end
end

for x = 1:dims(1)
for y = 1:dims(2)
for z = 1:dims(3)

    % use the observation data to calculate W
    for j = 1:num_raters

        l = obs.data{j}(x, y, z) + 1;

        % calculate the interpolated theta matrix
        thetau = interp_theta(theta, upds, j, l, x, y, z);

        if length(find(isnan(thetau)))
            keyboard;
        end

        % iterate over all of the labels
        for s = 1:num_labels

            % get the theta factor
            theta_factor = thetau(s);

            % iterate over all consensus values
            for c = 1:length(pcon)

                % get the label factor
                if (l == s)
                    label_factor = (1 - pcon(c)) + pcon(c) * theta_factor;
                else
                    label_factor = pcon(c) * theta_factor;
                end

                % calculate W
                W(x, y, z, s, c) = W(x, y, z, s, c) * label_factor;
            end
        end
    end

    % normalize for each voxel
    W(x, y, z, :, :) = W(x, y, z, :, :) / sum(sum(W(x, y, z, :, :), 5), 4);
end
end
end

