function [W C t_prior c_prior] = COLLATE_priors(obs, dims, num_raters,...
                                                num_labels,cval, num_con_levels)

% get an initial estimate of consensus and majority vote labels
C = -1 * ones([reshape(dims, [1 length(dims)]) 2]);
estimate = -1*ones(dims);

% iterate over each voxel
for x = 1:dims(1)
    for y = 1:dims(2)
        for z = 1:dims(3)

            % keep track of the maximum consensus value for a pixel
            max_cval = 0;
            % keep track of the majority vote label choice
            label_choice = -1;

            % iterate over each label
            for s = 1:num_labels
                curr_cval = 0;

                % iterate over each rater
                for j = 1:num_raters
                    if (obs.data{j}(x, y, z) == s-1)
                        curr_cval = curr_cval + 1;
                    end
                end
                curr_cval = curr_cval / num_raters;
                if curr_cval >= max_cval
                    max_cval = curr_cval;
                    label_choice = s-1;
                end
            end
            if max_cval >= cval;
                C(x, y, z, 1) = 2;
                C(x, y, z, 2) = label_choice;
            else
                C(x, y, z, 1) = 1;
            end
            estimate(x, y, z) = label_choice;
        end
    end
end

%
% construct W from C and estimate
%

% iterate over each label
for s = 1:num_labels
    for l = 1:dims(3)
        [x y] = find(estimate(:,:,l) == s-1);
        for i = 1:length(x)
            W(x(i), y(i), l, s, C(x(i), y(i), l, 1)) = 1;
        end
    end
end

%
% construct the data adaptive prior
%

% allocate space for the priors
t_prior = zeros([num_labels 1]);
c_prior = zeros([num_con_levels num_labels]);

% calculate the consensus prior
for s = 1:num_labels

    num_s = 0;
    for l = 1:dims(3)
        % calculate the f(Ci = c | Ti = s) matrix
        [sx sy] = find(estimate(:,:,l) == (s-1));

        if length(sx) > 0
            for i = 1:length(sx)
                sc = C(sx(i), sy(i), l, 1);
                c_prior(sc, s) = c_prior(sc, s) + 1;
            end
        end
        num_s = num_s + length(sx);
    end

    c_prior(:, s) = c_prior(:, s) / num_s;
end

% calculate the truth prior
for j = 1:num_raters
    for s = 1:num_labels
        t_prior(s) = t_prior(s) + length(find(obs.data{j} == s-1));
    end
end
t_prior = t_prior / sum(t_prior);

