function [new_truth theta W C] = ...
               COLLATE_spatial(obs, upds, dims, num_labels, bias, ...
                               bias_factor, epsilon, cval, pcon)

% reorder the rater, slice and volume numbers
[obs.raters num_raters] = reorder_array(obs.raters);

% construct the priors, initial W, truth and consensus priors
[W C t_prior c_prior] = COLLATE_priors(obs, dims, num_raters, ...
                                     num_labels, cval, length(pcon));

c_prior
t_prior
% initialize theta
theta = zeros(num_labels, num_labels, num_raters, upds.num);

% run staple
count = 0;
convergence_factor = Inf;
prev_diff = Inf;
while convergence_factor > 1.3
    % keep track of which iteration we are currently on
    count = count + 1;
    disp(['Beginning COLLATE Iteration: ', num2str(count)]);

    % calculate theta (estimate of the quality of each rater)
    theta_prev = theta;
    theta = COLLATE_calc_theta_spatial(W, obs, upds, num_raters, dims, ...
                                       bias, bias_factor, pcon);
    disp(['Theta done....']);

    % calculate W (the probability that each individual voxel belongs
    % to a given class).
    W = COLLATE_calc_w_spatial(theta, upds, num_raters, obs, dims, ...
                               pcon, C, t_prior, c_prior);
    disp(['W done....']);

    % calculate the difference between the sums of the diagonals of the
    % currently calculated theta and the previously calculated theta. This
    % value is compared to the threshold to test for convergence
    c_trace = 0;
    p_trace = 0;
    for i = 1:upds.num
        c_trace = c_trace + trace(sum(theta(:, :, :, i), 3));
        p_trace = p_trace + trace(sum(theta_prev(:, :, :, i), 3));
    end
    convergence_factor = prev_diff / abs(c_trace - p_trace);
    prev_diff = abs(c_trace - p_trace);
end

% calculate the staple estimate of the truth
new_truth = uint8(zeros(dims));

for x = 1:dims(1)
for y = 1:dims(2)
for z = 1:dims(3)
    W_vec = sum(squeeze(W(x, y, z, :, :)), 2);
    ind = find(W_vec == max(W_vec));
    if (length(ind) == 0)
       keyboard;
    end
    new_truth(x, y, z) = uint8(ind(1) - 1);
end
end
end

