function [new_truth theta W num_raters] = ...
                      STAPLE_boundary(obs, num_slices, num_voxels_per_im, ...
                                      num_voxels, bias, bias_factor, ...
                                      epsilon, length_im, width_im)

% get the ordered rater array and the number of raters
[obs.raters num_raters] = reorder_array(obs.raters);

% get the ordered slices array
obs.slices = reorder_array(obs.slices);

% get the ordered volumes array
obs.volumes = reorder_array(obs.volumes);

theta = zeros(2, 2, num_raters); % rater qualtiy variable

% initialize theta
for j = 1:size(theta, 1)
    for k = 1:size(theta, 2)
        for l = 1:size(theta, 3)
            if j == k
                theta(j, k, l) = .9999;
            else
                theta(j, k, l) = .0001;
            end
        end
    end
end

% normalize each row in theta
for k = 1:size(theta, 2)
    for l = 1:size(theta, 3)
        theta(:, k, l) = theta(:, k, l)./sum(theta(:, k, l));
    end
end

% run staple
count = 0;
convergence_factor = Inf;
while convergence_factor > epsilon
    % keep track of which iteration we are currently on
    count = count + 1;
    disp(['Beginning STAPLE Iteration Number: ', num2str(count)]);

    % calculate W (the probability that each individual voxel belongs
    % to a given class).
    W = calc_w_boundary(theta, obs, num_voxels, num_voxels_per_im, ...
                        num_slices, length_im, width_im);

    % calculate theta (estimate of the quality of each rater)
    theta_prev = theta;
    theta = calc_theta_boundary(W, obs, num_raters, theta_prev, bias, ...
                                bias_factor, num_slices, num_voxels_per_im, ...
                                length_im, width_im);

    % calculate the difference between the sums of the diagonals of the
    % currently calculated theta and the previously calculated theta. This
    % value is compared to the threshold to test for convergence
    next_sum = 0;
    current_sum = 0;
    for ii = 1:num_raters
        current_sum = current_sum + trace(theta(:,:,ii));
        next_sum = next_sum + trace(theta_prev(:,:,ii));
    end
    convergence_factor = abs(next_sum - current_sum) / (num_raters * 2);
end

% calculate the staple estimate of the truth
new_truth = 2 - sum(cumsum(W == repmat(max(W'), [2 1])', 2), 2);
new_truth = uint8(new_truth);
