function [new_truth theta W num_raters consensus] = ...
                      STAPLE_consensus(obs, num_slices, num_labels, ...
                                       num_voxels_per_im, num_voxels, bias, ...
                                       bias_factor, epsilon, cval, ...
                                       length_im, width_im)

% get the ordered rater array and the number of raters
[obs.raters num_raters] = reorder_array(obs.raters);

% get the ordered slices array
obs.slices = reorder_array(obs.slices);

% get the ordered volumes array
obs.volumes = reorder_array(obs.volumes);

% find consensus pixels
[consensus cfact] = find_consensus_pixels(obs, num_slices, ...
                                          num_voxels_per_im, num_voxels, ...
                                          num_labels, cval, length_im, ...
                                          width_im);

W = zeros(num_voxels, num_labels); % weighting variable
theta = zeros(num_labels, num_labels, num_raters); % rater qualtiy variable

% initialize theta
for j = 1:size(theta, 1)
    for k = 1:size(theta, 2)
        for l = 1:size(theta, 3)
            if j == k
                theta(j, k, l) = .9999;
            else
                theta(j, k, l) = .0001;% + (.0001*rand());
            end
        end
    end
end

% normalize each row in theta
for k = 1:size(theta, 2)
    for l = 1:size(theta, 3)
        theta(:, k, l) = theta(:, k, l)./sum(theta(:, k, l));
    end
end

% run staple
count = 0;
convergence_factor = Inf;
while convergence_factor > epsilon
    % keep track of which iteration we are currently on
    count = count + 1;
    disp(['Beginning STAPLE Iteration Number: ', num2str(count)]);

    % calculate W (the probability that each individual voxel belongs
    % to a given class).
    W = calc_w_consensus(theta, obs, num_voxels, num_voxels_per_im, ...
                         num_slices, consensus);

    % calculate theta (estimate of the quality of each rater)
    theta_prev = theta;
    theta = calc_theta_consensus(W, obs, num_raters, theta_prev, ...
                                 bias, bias_factor, num_slices, ...
                                 num_voxels_per_im, consensus, cfact);

    % calculate the difference between the sums of the diagonals of the
    % currently calculated theta and the previously calculated theta. This
    % value is compared to the threshold to test for convergence
    c_trace = trace(sum(theta, 3));
    p_trace = trace(sum(theta_prev, 3));
    convergence_factor = abs(c_trace - p_trace) / (num_raters * num_labels);
end

% calculate the staple estimate of the truth
new_truth = num_labels - ...
            sum(cumsum(W == repmat(max(W'), [num_labels 1])', 2), 2);
new_truth(consensus >= 0) = consensus(consensus >= 0);
new_truth = uint8(new_truth);

