function [new_truth theta W num_raters consensus] = ...
               STAPLE_consensus_theory(obs, num_slices, num_labels, ...
                                       num_voxels_per_im, num_voxels, bias, ...
                                       bias_factor, epsilon, cval, pcon, ...
                                       length_im, width_im)

% reorder the rater, slice and volume numbers
[obs.raters num_raters] = reorder_array(obs.raters);
obs.slices = reorder_array(obs.slices);
obs.volumes = reorder_array(obs.volumes);

% construct the priors, initial W, truth and consensus priors
[W t_prior c_prior] = priors_consensus_theory(obs, num_voxels, ...
                                              num_voxels_per_im, ...
                                              num_slices, num_labels, ...
                                              cval, length(pcon), ...
                                              length_im, width_im);
c_prior
t_prior

% initialize theta
theta = zeros(num_labels, num_labels, num_raters); % rater qualtiy variable

% run staple
count = 0;
convergence_factor = Inf;
prev_diff = Inf;
while convergence_factor > epsilon
    % keep track of which iteration we are currently on
    count = count + 1;
    disp(['Beginning STAPLE Iteration Number: ', num2str(count)]);

    % calculate theta (estimate of the quality of each rater)
    theta_prev = theta;
    theta = calc_theta_consensus_theory(W, obs, num_raters, ...
                                        bias, bias_factor, num_slices, ...
                                        num_voxels_per_im, pcon);

    % calculate W (the probability that each individual voxel belongs
    % to a given class).
    W = calc_w_consensus_theory(theta, obs, num_voxels, num_voxels_per_im, ...
                                num_slices, pcon, t_prior, c_prior);

    % calculate the difference between the sums of the diagonals of the
    % currently calculated theta and the previously calculated theta. This
    % value is compared to the threshold to test for convergence
    c_trace = trace(sum(theta, 3));
    p_trace = trace(sum(theta_prev, 3));
    convergence_factor = abs((p_trace - c_trace) / (num_raters * num_labels));
    %convergence_factor = abs(c_trace - p_trace) / (num_raters * num_labels)
end

% calculate the staple estimate of the truth
W_s = sum(W, 3);
new_truth = num_labels - ...
            sum(cumsum(W_s == repmat(max(W_s'), [num_labels 1])', 2), 2);
new_truth = uint8(new_truth);

