function [new_truth theta W num_raters] = ...
          STAPLE_ideal_theta_consensus(obs, num_slices, num_volumes, ...
                                       num_labels, num_voxels_per_im, ...
                                       num_voxels, truth, cval, ...
                                       length_im, width_im)

% first reorder the arrays to start at a value of 1
obs.slices = reorder_array(obs.slices);
obs.volumes = reorder_array(obs.volumes);
[obs.raters num_raters] = reorder_array(obs.raters);

% find consensus pixels
[consensus cfact] = find_consensus_pixels(obs, num_slices, ...
                                          num_voxels_per_im, num_voxels, ...
                                          num_labels, cval, length_im, ...
                                          width_im);

% construct the ideal theta
theta = construct_ideal_theta_consensus(obs, truth, num_slices, num_volumes, ...
                                        num_labels, num_voxels_per_im, cfact);

% calculate W
W = calc_w(theta, obs, num_voxels, num_voxels_per_im, num_slices);

% calculate the staple estimate of the truth
new_truth = num_labels - ...
            sum(cumsum(W == repmat(max(W'), [num_labels 1])', 2), 2);
new_truth(consensus >= 0) = consensus(consensus >= 0);
new_truth = uint8(new_truth);

