
dirs = {'../task1'; '../task1-4'; '../task3'; '../task3-17'; ...
        '../task4'; '../task4-17'; '../task5'; '../task5-17'};
truth_dir = 'truth';
estimate_dir = 'staple_estimates_bias';
data_dir = 'data';

num_slices_vec = [64, 64, 39, 44, 61, 70, 62, 110];
num_volumes_vec = [1, 1, 1, 1, 1, 1, 1, 1];
length_im_vec = [64, 64, 61, 70, 62, 110, 61, 70];
width_im_vec = [64, 64, 62, 110, 102, 114, 102, 114];
st_slice_vec = [1, 1, 62, 71, 1, 1, 1, 1];
st_volume_vec = [1, 1, 3, 3, 2, 2, 4, 4];
type = [0, 0, 0, 1, 0, 1, 0, 1];

label_accuracy = -1 * ones(6, 1000);
ind_accuracy = -1 * ones(6, 50000);

for i = 1:length(dirs)
    d = dirs{i};

    num_slices = num_slices_vec(i);
    num_volumes = num_volumes_vec(i);
    length_im = length_im_vec(i);
    width_im = width_im_vec(i);
    num_pixels = length_im * width_im;
    st_slice = st_slice_vec(i);
    st_volume = st_volume_vec(i);

    % gather all of the individual observations
    truth_data = zeros(num_volumes, num_slices, length_im, width_im);
    estimate_data = zeros(size(truth_data));
    ind_data = -1 * ones(num_volumes, num_slices, length_im, width_im, 150);

    % gather all of the estimates
    for v = 1:num_volumes
        for s = 1:num_slices
            estimate_data(v, s, :, :) = imread([d, '/', estimate_dir, ...
                                                '/estimate', ...
                                                '_vol', num2str(v), ...
                                                '_sl', num2str(s), ...
                                                '.png']);
        end
    end

    % gather all of the individual data
    fnames = dir([d, '/', data_dir, '/*.png']);
    for i = 1:length(fnames)
        fname = [d, '/', data_dir, '/', fnames(i).name];
        % get the volume and slice numbers
        vol = regexp(char(regexp(fname, 'vol[0-9]+', 'match')), '[0-9]+', 'match');
        sl = regexp(char(regexp(fname, 'sl[0-9]+', 'match')), '[0-9]+', 'match');
        vol = str2num(vol{1}) - (st_volume - 1);
        sl = str2num(sl{1}) - (st_slice - 1);

        % find which index we are at for the given volume/slice
        n = find(ind_data(vol, sl, 1, 1, :) == -1);

        ind_data(vol, sl, :, :, n(1)) = imread(fname);
    end

    % gather the truth data
    if type
        truth_fnames = dir([d, '/', truth_dir, '/*.png']);
        for i = 1:num_slices
            fname = truth_fnames(i).name;
            sl = regexp(char(regexp(fname, 'sl[0-9]+', 'match')), '[0-9]+', 'match');
            sl = str2num(sl{1});
            truth_data(1, sl, :, :) = imread([d, '/', truth_dir, '/', fname]);
        end
    else
        truth_fnames = dir([d, '/', truth_dir, '/*.png']);
        for i = 1:num_slices
            fname = truth_fnames(i).name;
            truth_data(1, i, :, :) = imread([d, '/', truth_dir, '/', fname]);
        end
    end

    for i = 1:num_slices
        % calculate the accuracy for the estimates
        diff_data = double(estimate_data(1, i, :, :)) - ...
                    double(truth_data(1, i, :, :));
        num_diff_pixels = length(diff_data(abs(diff_data) > 0));

        s = length(unique(truth_data(1, i, :, :)));
        n = find(label_accuracy(s, :) < 0);
        n = n(1);
        label_accuracy(s, n) = 100 - 100 * num_diff_pixels / num_pixels;

        % calculate the accuracy for the individual observations
        n = find(ind_data(1, i, 1, 1, :) == -1);
        num_obs = n(1) - 1;
        for j = 1:num_obs
            diff_data = double(ind_data(1, i, :, :, j)) - ...
                        double(truth_data(1, i, :, :));
            num_diff_pixels = length(diff_data(abs(diff_data) > 0));
            n = find(ind_accuracy(s, :) < 0);
            n = n(1);
            ind_accuracy(s, n) = 100 - 100 * num_diff_pixels / num_pixels;
        end
    end
end

label_accuracy(label_accuracy == -1) = NaN;
label_ave = zeros(6, 1);
label_std = zeros(6, 1);
for i = 1:6
    label_ave(i) = mean(label_accuracy(i, find(~isnan(label_accuracy(i, :)))));
    label_std(i) = std(label_accuracy(i, find(~isnan(label_accuracy(i, :)))));
end

ind_accuracy(ind_accuracy == -1) = NaN;
ind_ave = zeros(6, 1);
ind_std = zeros(6, 1);
for i = 1:6
    ind_ave(i) = mean(ind_accuracy(i, find(~isnan(ind_accuracy(i, :)))));
    ind_std(i) = std(ind_accuracy(i, find(~isnan(ind_accuracy(i, :)))));
end

figure(1);
subplot(4, 2, [1 3 5]);
boxplot(label_accuracy');
ylabel('Average Accuracy');
xlim([0.5 6.5]);
ylim([0 100]);
set(gca,'XTickLabel',{' '})

subplot(4, 2, 7);
num_staples = zeros(1, size(label_accuracy, 1));
for i = 1:size(label_accuracy, 1)
    num_staples(i) = length(label_accuracy(~isnan(label_accuracy(i, :))));
end
bar(num_staples);
xlabel('Number of  Labels');
ylabel('# Observations');
xlim([0.5 6.5]);


subplot(4, 2, [2 4 6]);
boxplot(ind_accuracy');
ylabel('Average Accuracy');
xlim([0.5 6.5]);
ylim([0 100]);
set(gca,'XTickLabel',{' '})

subplot(4, 2, 8);
num_ind = zeros(1, size(ind_accuracy, 1));
for i = 1:size(ind_accuracy, 1)
    num_ind(i) = length(ind_accuracy(~isnan(ind_accuracy(i, :))));
end
bar(num_ind);
xlabel('Number of  Labels');
ylabel('# Observations');
xlim([0.5 6.5]);
