function [obs_out] = add_obs(obs_in, fname, num_voxels_per_im)
% function that adds an observation to the input observation struct

% use regular expressions to find the parameters we need
rater = regexp(char(regexp(fname, 'rater[0-9]+', 'match')), '[0-9]+', 'match');
vol = regexp(char(regexp(fname, 'vol[0-9]+', 'match')), '[0-9]+', 'match');
sl = regexp(char(regexp(fname, 'sl[0-9]+', 'match')), '[0-9]+', 'match');

if (isempty(rater) || isempty(vol) || isempty(sl))
    warning(['Observation not added: ', fname]);
    obs_out = obs_in;
    return;
end

% save it to the output observation struct
obs_out = obs_in;
obs_ind = obs_in.num + 1;
obs_out.num = obs_ind;
obs_out.raters(obs_ind) = str2num(rater{1});
obs_out.volumes(obs_ind) = str2num(vol{1});
obs_out.slices(obs_ind) = str2num(sl{1});
obs_out.data{obs_ind} = reshape(imread(fname), [1, num_voxels_per_im]);


