function theta = calc_theta_boundary(W, obs, num_raters, theta_prev, ...
                                     bias, bias_factor, num_slices, ...
                                     num_voxels_per_im, length_im, width_im)

% number of voxels comes from the size of W
num_voxels = size(W, 1);

% initialize theta
theta = zeros([2 2 num_raters]);

% Pre-init bias
if bias == 1
    bias_confusion = diag(ones([1 2]));
    for j = 1:num_raters
        theta(:,:,j) = bias_confusion * bias_factor * (num_voxels / num_raters);
    end
end

% Actual Staple
for i = 1:obs.num
    volume = obs.volumes(i);
    slice = obs.slices(i);
    rater = obs.raters(i);
    data = obs.data{i};
    vox = get_voxel_num(volume, slice, 0, num_slices, num_voxels_per_im);
    u_boundarypix = find_boundary_pixels(data, 1, length_im, width_im, ...
                                         num_voxels_per_im);
    for j = 1:length(data)
        for b = 1:2
            % calculate theta value
            theta(u_boundarypix(j) + 1, b, rater) = ...
                    theta(u_boundarypix(j) + 1, b, rater) + W(vox + j, b);
        end
    end
end

% normalize theta
for l = 1:2
    for j = 1:num_raters
        if sum(theta(:, l, j)) == 0
            theta(:, l, j) = theta_prev(:, l, j);
        end
        theta(:, l, j) = theta(:, l, j) ./ sum(theta(:, l, j));
    end
end

