function theta = calc_theta_consensus(W, obs, num_raters, theta_prev, bias, ...
                                      bias_factor, num_slices, ...
                                      num_voxels_per_im, consensus, cfact)

% number of labels and number of voxels comes from the size of W
num_labels = size(W, 2);
num_voxels = size(W, 1);

% initialize theta
theta = zeros([num_labels num_labels num_raters]);

% Pre-init bias
if bias == 1
    bias_confusion = diag(ones([1 num_labels]));
    for j = 1:num_raters
        theta(:,:,j) = bias_confusion * bias_factor * (num_voxels / num_raters);
    end
end

% Actual Staple
for i = 1:obs.num
    volume = obs.volumes(i);
    slice = obs.slices(i);
    rater = obs.raters(i);
    data = obs.data{i};
    vox = get_voxel_num(volume, slice, 0, num_slices, num_voxels_per_im);
    %inds = find(consensus(vox + (1:length(data))) == -1);
    %for m = 1:length(inds)
    %    j = inds(m);
    for j = 1:length(data)
        for s = 1:num_labels
            % calculate theta value
            theta(data(j)+1, s, rater) = theta(data(j)+1, s, rater) + ...
                                         cfact(vox + j) * W(vox + j, s);
        end
    end
end

% normalize theta
for l = 1:num_labels
    for j = 1:num_raters
        if sum(theta(:, l, j)) == 0
            theta(:, l, j) = theta_prev(:, l, j);
        end
        theta(:, l, j) = theta(:, l, j) ./ sum(theta(:, l, j));
    end
end

