function theta = calc_theta_consensus_theory(W, obs, num_raters, bias, ...
                                             bias_factor, num_slices, ...
                                             num_voxels_per_im, pcon)
% assumes that each rater (j) observed each slice exactly once

% number of labels and number of voxels comes from the size of W
num_labels = size(W, 2);
num_voxels = size(W, 1);

% initialize theta
theta = zeros([num_labels num_labels num_raters]);

% Pre-init bias
if bias == 1
    bias_confusion = diag(ones([1 num_labels]));
    for j = 1:num_raters
        theta(:,:,j) = bias_confusion * bias_factor * (num_voxels / num_raters);
    end
end

% initialize lambda
lambda = zeros(num_raters, num_labels);

x = [];

% construct both the lambda and theta values
for j = 1:num_raters

    % find the indices of the raters in slice order
    rater_inds = find(obs.raters == j);
    [y i] = sort(obs.slices(rater_inds));
    rater_inds = rater_inds(i);

    x = [rater_inds; x];

    % get the data from each rater for every voxel
    data = [obs.data{rater_inds}];

    % iterate over every column in theta
    for s = 1:num_labels

        % calculate all of the factors necessary to calculate lambda and theta
        Q = sum(sum(W(find(data+1 ~= s), s, :)));
        W0 = sum(W(find(data+1 == s), s, 1));
        W1 = sum(W(find(data+1 == s), s, 2));

        % calculate alpha
        alpha = 1;
        % calculate beta
        beta = Q + pcon(1)*W0 + pcon(2)*W1;
        % calculate gamma
        gamma = prod(pcon) * Q * (Q + W0 + W1);

        % calculate the value of lambda for 'j' rater and 's' label
        lambda(j, s) = (-beta - sqrt(beta^2 - 4 * alpha * gamma)) / (2 * alpha);

        % calculate off-diagonal theta
        for l = 1:num_labels
            if (l ~= s)
                l_inds = find(data+1 == l);
                theta(l, s, j) = sum(sum(W(l_inds, s, :))) / (-lambda(j, s));
            end
        end

        % calculate on-diagonal theta
        a = prod(pcon) * lambda(j, s);
        b = sum(pcon.^2) * lambda(j, s) + prod(pcon) * (W0 + W1);
        c = a + (pcon(1)^2) * W0 + (pcon(2)^2) * W1;
        theta(s, s, j) = (-b - sqrt(b^2 - 4*a*c)) / (2*a);

        if lambda(j, s) == 0
            theta(:, s, j) = 0;
            theta(s, s, j) = 1;
        end

    end
end

