function W = calc_w_consensus_theory(theta, obs, num_voxels, ...
                                     num_voxels_per_im, num_slices, pcon, ...
                                     t_prior, c_prior)

% find the number of labels
num_labels = size(theta, 1);
% initialze W
W = ones(num_voxels, num_labels, length(pcon));

%
% use the data adaptive prior
%
for s = 1:num_labels
    for c = 1:length(pcon)
        W(:, s, c) = W(:, s, c) * t_prior(s) * c_prior(c, s);
    end
end

% use the observation data to calculate W
for i = 1:obs.num
    volume = obs.volumes(i);
    slice = obs.slices(i);
    rater = obs.raters(i);
    data = obs.data{i};
    vox = get_voxel_num(volume, slice, 0, num_slices, num_voxels_per_im);

    % iterate over all of the data in the current observation
    for v = 1:length(data)

        % iterate over all of the labels
        for s = 1:num_labels

            % iterate over all consensus values
            for c = 1:length(pcon)

                % get the theta factor
                theta_factor = theta(data(v) + 1, s, rater);

                % get the label factor
                if (data(v) + 1 == s)
                    label_factor = (1 - pcon(c)) + pcon(c) * theta_factor;
                else
                    label_factor = pcon(c) * theta_factor;
                end

                % calculate W
                W(vox + v, s, c) = W(vox + v, s, c) * label_factor;
            end
        end
    end
end

% normalize for each voxel
W = W ./ (repmat(sum(sum(W, 3), 2), [1 num_labels length(pcon)]));

