function theta = construct_ideal_theta(obs, truth, num_slices, num_volumes, ...
                                       num_labels, num_voxels_per_im)


% first reorder the arrays to start at a value of 1
slices = reorder_array(obs.slices);
volumes = reorder_array(obs.volumes);
[raters num_raters] = reorder_array(obs.raters);

% allocate space for theta
theta = zeros([num_labels num_labels num_raters]);

% construct the ideal theta
for i = 1:obs.num
    v= volumes(i);
    s= slices(i);
    rater = raters(i);
    data = obs.data{i};
    bind = get_voxel_num(v, s, 1, num_slices, num_voxels_per_im);
    eind = bind + (num_voxels_per_im - 1);
    tr = truth(bind:eind); % add 1 so the label numbers start at 1
    for j = 1:length(data)
        theta(data(j)+1, tr(j)+1, rater) = theta(data(j)+1, tr(j)+1, rater) + 1;
    end
end

% initialize a fake theta, used in situations where a label was never used
theta_init = zeros(size(theta));
for j = 1:num_raters
    theta_init(:,:,j) = diag(ones([1 num_labels]));
end

% normalize theta
for l = 1:num_labels
    for j = 1:num_raters
        if sum(theta(:, l, j)) == 0
            theta(:, l, j) = 0;%theta_init(:, l, j);
        else
            theta(:, l, j) = theta(:, l, j) ./ sum(theta(:, l, j));
        end
    end
end

