function [results] = coverage_accuracy(monte_carlo_runs, st_cov, end_cov, ...
                                       num_slices, st_slice_truth, ...
                                       num_voxels_per_im, num_voxels, ...
                                       truth_dir, data_dir, st_slice, ...
                                       num_labels, epsilon, bias, bias_factor)

% construct the actual truth for determining accuracy
truth = get_estimates(num_slices, st_slice_truth, ...
                      num_voxels_per_im, num_voxels, truth_dir);

% allocate space for the results
results = zeros(monte_carlo_runs, num_slices, end_cov - st_cov + 1);

% run the simulation
for r = 1:monte_carlo_runs
    disp(['Monte Carlo Simulation Number: ', num2str(r)]);
    % get a cell array of usable filenames
    [ufn] = find_usable_fnames_online(data_dir, num_slices, st_slice);

    % iterate over each coverage amount
    for c = st_cov:end_cov

        % load the observations up to the desired number of coverages
        num_obs = c * num_slices;
        obs = struct('raters', -1 * ones([num_obs 1]), ...
                     'slices', -1 * ones([num_obs 1]), ...
                     'volumes', -1 * ones([num_obs 1]), ...
                     'num', 0);
        obs.data = cell(num_obs, 1);
        for i = 1:num_slices
            for j = 1:c
                obs = add_obs(obs, [data_dir, ufn{i}{j}], num_voxels_per_im);
            end
        end

        % run STAPLE
        [new_truth theta W num_raters] = STAPLE(obs, num_slices, num_labels, ...
                                                num_voxels_per_im, ...
                                                num_voxels, bias, ...
                                                bias_factor, epsilon);
        new_truth = double(new_truth);

        % determine the accuracy of each voxel
        tdiff = abs(new_truth - truth);

        % determine the accuracy of each slice
        for i = 1:num_slices
            bind = (num_voxels_per_im) * (i - 1) + 1;
            eind = num_voxels_per_im * i;
            sl_tdiff = tdiff(bind:eind);
            results(r, i, c - st_cov + 1) = ...
                        (length(sl_tdiff(sl_tdiff == 0))) / length(sl_tdiff);
        end
    end
end

% plot the results
C = {'r', 'g', 'b', 'c', 'm'};
figure(1);
clf;
for i = 1:end_cov-st_cov+1
    x = 1:num_slices;
    y = mean(results(:,:,i));
    e = std(results(:,:,i));
    errorbar(x, y, e, C{i});
    hold on;
end
hold off;
xlabel('Slice Number');
ylabel('% Pixels Correct')
legend({'3 Coverages'; '4 Coverages'; '5 Coverages'; ...
        '6 Coverages'; '7 Coverages'}, 0);
