function boundarypix = find_boundary_pixels(truth, num_slices, length_im, ...
                                            width_im, num_voxels_per_im)

% allocate space for the boundary pixel vector
boundarypix = zeros(size(truth));

% find the unique values in the truth
uniquetruth = unique(truth);

% iterate over each slice
for j = 1:num_slices
    % calculate the indices of the current slice
    bind = (j-1) * num_voxels_per_im + 1;
    eind = j * num_voxels_per_im;

    % isolate the current slice
    slice = reshape(truth(bind:eind), [length_im, width_im]);

    % iterate over all of the pixels in the slice
    for m = 1:length_im
        for n = 1:width_im
            % assume the pixel is not a boundary at first
            b = 0;

            % find the value at the current pixel
            v = slice(m, n);

            % iterate over all of the cases to determine if the pixel is
            % a boundary pixel or not
            if (m < length_im && slice(m+1, n) ~= v)
                b = 1;
            end
            if (m > 1 && slice(m-1, n) ~= v)
                b = 1;
            end
            if (n < width_im && slice(m, n+1) ~= v)
                b = 1;
            end
            if (n > 1 && slice(m, n-1) ~= v)
                b = 1;
            end
            if (m < length_im && n < width_im && slice(m+1, n+1) ~= v)
                b = 1;
            end
            if (m < length_im && n > 1 && slice(m+1, n-1) ~= v)
                b = 1;
            end
            if (m > 1 && n < width_im && slice(m-1, n+1) ~= v)
                b = 1;
            end
            if (m > 1 && n > 1 && slice(m-1, n-1) ~= v)
                b = 1;
            end

            % is it a boundary pixel ?
            if b > 0
                % find which pixel in the main truth vector pixel corresponds to
                p = bind + (n - 1) * length_im + m - 1;
                boundarypix(p) = 1;
            end
        end
    end
end

%% for a sanity check show each of the images
%for j = 1:num_slices
%    % calculate the indices of the current slice
%    bind = (j-1) * num_voxels_per_im + 1;
%    eind = j * num_voxels_per_im;
%
%    % isolate the current slice
%    slice = reshape(boundarypix(bind:eind), [length_im, width_im]);
%
%    imagesc(slice);
%    pause();
%end
