function [consensus cfact] = find_consensus_pixels(obs, num_slices, ...
                                           num_voxels_per_im, num_voxels, ...
                                           num_labels, cval, length_im, ...
                                           width_im)

slice_rater_list = zeros([num_slices 1]);
% find out how man unique raters evaluated each slice
for s = 1:num_slices
    % find the inds where this slice was observed
    inds = find(obs.slices == s);
    raters = obs.raters(inds);
    slice_rater_list(s) = length(unique(raters));
end

% allocate space for the voxel array
varr = zeros([num_voxels num_labels]);

% use the observation data to calculate W
for i = 1:obs.num
    volume = obs.volumes(i);
    slice = obs.slices(i);
    rater = obs.raters(i);
    data = obs.data{i};
    vox = get_voxel_num(volume, slice, 0, num_slices, num_voxels_per_im);

    % make sure at least 3 raters rated the slice
    if (slice_rater_list(slice) >= 3)
        for v = 1:num_voxels_per_im
            varr(vox + v, data(v) + 1) = varr(vox + v, data(v) + 1) + 1;
        end
    end
end

% normalize for each voxel
varr = varr ./ (repmat(sum(varr'), [num_labels 1])');
varr(isnan(varr)) = 0;

% populate the consensus array
consensus = -1 * ones([1 num_voxels]);
inds = find(max(varr') >= cval);
for i = 1:length(inds)
    j = find(varr(inds(i), :) == max(varr(inds(i), :)));
    consensus(inds(i)) = j - 1;
end

% calculate the linear consensus factor
cfact_lin = 1 - max(varr');

% map from 0 to 1
cfact_map = (cfact_lin - min(cfact_lin)) / (max(cfact_lin) - min(cfact_lin));

% apply the probability distribution (Generalised Logistic Function)
% http://en.wikipedia.org/wiki/Generalised_logistic_function
A = 0; % the lower asymptote
K = 1; % the upper asymptote
B = 25; % the growth rate
Q = 1.0; % depends on the value Y(0)
v = 1.0; % v > 0; affects near which asymptote maximum growth occurs
M = 0.3; % the time of maximum growth if Q = v
cfact = A + (K - A) ./ ((1 + Q*exp(-1*B*(cfact_map - M))).^(1/v));

% plot the results
% plot(cfact_map, cfact, 'b*');

%% display the truth on figure 1
%truth = get_estimates(num_slices, 30162, num_voxels_per_im, ...
%                      num_voxels, '../task3/truth');
%
%% display the heatmap of cfact on figure 2
%for s = 1:num_slices
%    % calculate the image number
%    i = s;
%    % calculate the indices for each image
%    bind = num_voxels_per_im*(i-1)+1; % beginning index
%    eind = num_voxels_per_im*i; % ending index
%
%    im1 = reshape(truth(bind:eind), length_im, width_im);
%    cmap = [1 1 1; 0 0 1; 0 1 0; 1 0 1; 1 0 0; 1 1 0];
%
%    figure(1);
%    imagesc(im1);
%    caxis([0 5]);
%    colormap(cmap);
%    colorbar;
%
%    im2 = reshape(cfact(bind:eind), length_im, width_im);
%
%    % set the figure
%    figure(2);
%    % plot it using imagesc
%    imagesc(im2);
%    caxis([0 1]);
%    colormap('Copper');
%    colorbar;
%end

