function [varargout] = get_coverage_obs_new(obs, coverages, varargin)
% return the requested number of coverages from obs

if nargin == 2
    % if they do not specify which slices to include, then include all of them
    slice_list = unique(obs.slices)';
elseif nargin == 3
    % if specified then...
    slice_list = varargin{1};
else
    error('Invalid number of input arguments to get_coverage_obs.m');
end

% get the unique rater numbers
uniqueraters = unique(obs.raters);

% the number of slice ratings for a full coverage
full_num_rated_slices = length(slice_list);

% construct a cell array to handle the data
valid_raters = cell(length(uniqueraters), 2);

num_valid_raters = 0;

% iterate over each rater to determine if they labeled each slice
for i = 1:length(uniqueraters)

    % find all of the observations performed by this rater
    rater_inds = find(obs.raters == uniqueraters(i));

    % find all of the labelings within the st_slice to end_slice range
    slice_inds = [];
    for k = 1:length(slice_list)
        inds = rater_inds(find(obs.slices(rater_inds) == slice_list(k)));
        slice_inds = union(inds, slice_inds);
    end

    % the number of slice ratings for this rater
    num_rated_slices = length(unique(obs.slices(slice_inds)));

    % they did a full coverage!
    if num_rated_slices == full_num_rated_slices

        % increment the number of valid raters
        num_valid_raters = num_valid_raters + 1;

        slice_ind_list = zeros(num_rated_slices, 1);

        % find the index for each rater for each observation
        count = 0;
        for j = slice_list
            single_slice_inds = rater_inds(find(obs.slices(rater_inds) == j));
            num_obs = length(single_slice_inds);
            rp = randperm(num_obs);
            count = count + 1;
            slice_ind_list(count) = single_slice_inds(rp(1));
        end
        valid_raters{num_valid_raters, 1} = uniqueraters(i);
        valid_raters{num_valid_raters, 2} = slice_ind_list;
    end
end

% quick error check
if (num_valid_raters < coverages)
    error('Not enough full coverages found');
end

% make the final list of valid raters
valid_raters = valid_raters(1:num_valid_raters, :);

% randomly select the rater order
rater_nums = randperm(num_valid_raters);

% construct the list of indices to use
inds = [];
for i = 1:coverages
    inds = [[valid_raters{rater_nums(i), 2}]', inds];
end

% reorder the observations
obsnew.raters = obs.raters(inds);
obsnew.slices = obs.slices(inds);
obsnew.volumes = obs.volumes(inds);
obsnew.data = obs.data(inds);
obsnew.num = length(inds);

% set the output arguments
if nargout == 1
    varargout{1} = obsnew;
elseif nargout == 2
    varargout{1} = obsnew;
    varargout{2} = num_valid_raters;
else
    error('Too many output arguments to get_coverage_obs.m');
end
