function truth = get_estimates(num_slices, st_slice, num_voxels_per_im, ...
                               num_voxels, truth_dir)

% pre-allocate the truth vector
truth = zeros([num_voxels 1]);

% get a list of all of the filenames
fnames = dir([truth_dir, '/*.png']);

% make sure that there are exactly the same number of slices as expected
if (num_slices ~= length(fnames))
    error('Something is wrong');
end

% iterate over each slice
for i = 1:num_slices
    % iterate over each filename
    f = fnames(i).name;

    % get the slice number from the filename
    sl = regexp(char(regexp(f, 'sl[0-9]+', 'match')), '[0-9]+', 'match');
    sl = str2num(sl{1}) - st_slice + 1;

    % read the image from the filename
    im = imread([truth_dir, '/', f]);

    % reshape the image to the appropriate 1D array
    im_1 = reshape(im, num_voxels_per_im, 1);

    % index the 1D array into the truth vector
    bind = (sl-1) * num_voxels_per_im + 1;
    eind = bind + num_voxels_per_im - 1;
    truth(bind:eind) = im_1;
end

