function rater_accuracy = get_rater_accuracy(obs, truth, num_slices, ...
                                             num_volumes, num_labels, ...
                                             num_voxels_per_im)

% first reorder the arrays to start at a value of 1
obs.slices = reorder_array(obs.slices);
obs.volumes = reorder_array(obs.volumes);
[obs.raters num_raters] = reorder_array(obs.raters);

% get the appropriate information from the observations
[rater_list slice_list] = get_obs_info(obs);

% construct the pixel value array
p_val = zeros([length(truth) 1]);

% iterate over each observation
for i = 1:obs.num
    volume = obs.volumes(i);
    slice = obs.slices(i);
    rater = obs.raters(i);
    data = obs.data{i};

    % find where we are in the truth array
    bind = get_voxel_num(volume, slice, 1, num_slices, num_voxels_per_im);
    eind = bind + (num_voxels_per_im - 1);

    % get the truth segment
    tr = truth(bind:eind);

    % construct the pixel value array
    p_val(bind:eind) = p_val(bind:eind) + ...
                        (tr == double(data)') / slice_list(slice, 2);
end
keyboard;


% allocate space for rater_accuracy
rater_accuracy = cell([num_raters 1]);

% iterate over each rater
for i = 1:num_raters
    % find all of the observations that were performed by that rater
    r_inds = find(obs.raters == i);

    % initialize the index in the cell array for each rater
    rater_accuracy{i} = zeros([length(r_inds) 1]);

    % iterate over each observation performed by that rater
    for j = 1:length(r_inds)
        % get the observation index
        o = r_inds(j);

        % get the observation information
        slice = obs.slices(o);
        volume = obs.volumes(o);
        data = obs.data{o};

        % get the truth data for that slice / volume
        bind = get_voxel_num(volume, slice, 1, num_slices, num_voxels_per_im);
        eind = bind + (num_voxels_per_im - 1);

        % get the truth segment
        tr = truth(bind:eind);
        % get the pixel value array segment
        pv = p_val(bind:eind);

        % calculate the difference between the observed data and the truth
        diff = abs(tr' - double(data)) ~= 0;

        rater_accuracy{i}(j) = sum(1 - p_val(diff == 0)) - sum(p_val(diff > 0));
    end
end

