function [W t_prior c_prior] = priors_consensus_theory(obs, num_voxels, ...
                                                       num_voxels_per_im, ...
                                                       num_slices, ...
                                                       num_labels, cval, ...
                                                       num_con_levels, ...
                                                       length_im, width_im)

% make an initial estimate of C
C = find_consensus_pixels(obs, num_slices, num_voxels_per_im, num_voxels, ...
                          num_labels, cval, 0, 0);
C(C >= 0) = 2; % consensus
C(C == -1) = 1; % non-consensus (confusion)

% make an initial estimate of T
estimate = majority_vote(obs, num_slices, num_voxels_per_im, num_voxels, ...
                         num_labels);

%
% construct W from C and estimate
%

% allocate space for W
W = zeros(num_voxels, num_labels, num_con_levels);

% iterate over each label
for s = 1:num_labels
    s_inds = find(estimate == s-1);
    for i = 1:length(s_inds)
        W(s_inds(i), s, C(s_inds(i))) = 1;
    end
end

%
% construct the data adaptive prior
%

% allocate space for the priors
t_prior = zeros([num_labels 1]);
c_prior = zeros([num_con_levels num_labels]);
for s = 1:num_labels
    % calculate the f(Ci = c | Ti = s) matrix
    for c = 1:num_con_levels
        s_inds = find(estimate == (s-1));
        if length(s_inds) == 0
            if c == 1
                c_prior(c, s) = 1;
            else
                c_prior(c, s) = 0;
            end
        else
            c_inds = find(C(s_inds) == c);
            c_prior(c, s) = length(c_inds) / length(s_inds);
        end
    end

    if (length_im < 1)
        c_prior(1, s) = length_im;
        c_prior(2, s) = 1 - length_im;
    end

end

% calculate the f(Ti = s) prior
for i = 1:obs.num
    for s = 1:num_labels
        t_prior(s) = t_prior(s) + length(find(obs.data{i} == s-1));
    end
end
% normalize
t_prior = t_prior / sum(t_prior);
