function [err_im num_obs] = slice_error_dist(obs, truth, slice, volume, ...
                                             num_slices, num_voxels_per_im, ...
                                             length_im, width_im)

% find the segment of the truth corresponding the current slice / volume
bind = get_voxel_num(volume, slice, 1, num_slices, num_voxels_per_im);
eind = bind + (num_voxels_per_im - 1);
tr = truth(bind:eind); % truth segment

% allocate space for the result
err_im = zeros([length_im, width_im]);

% first, reorder the slice numbers and volume numbers in the observation
% struct to begin at 1
slices = reorder_array(obs.slices);
volumes = reorder_array(obs.volumes);

% find the indices of all the observations that are monitoring the correct
% slices and volumes
inds1 = find(slices == slice);
inds2 = find(volumes == volume);
inds = intersect(inds1, inds2);

num_obs = length(inds);
% iterate over all of the found observation numbers
for i = 1:num_obs
    ind = inds(i);

    % get the data from the current observation
    obsdata = obs.data{ind};

    % calculate the difference between the observed data and the truth
    diff = abs(tr' - double(obsdata)) > 0;

    % reshape to be the size of the output image
    diff = reshape(diff, [length_im width_im]);

    % indicate on the error image where the differences are
    err_im = err_im + diff;
end

