function view_save_estimates(new_truth, num_volumes, num_slices, out_dir, ...
                             length_im, width_im, num_voxels_per_im, ...
                             save_output_ims, view_output_ims)

% first, make sure the output directory exists
if ~exist(out_dir, 'dir')
    mkdir(out_dir);
end

% if desired, save the output images as png files
for v = 1:num_volumes
    for s = 1:num_slices
        % calculate the image number
        i = num_slices*(v - 1) + s;
        % calculate the indices for each image
        bind = num_voxels_per_im*(i-1)+1; % beginning index
        eind = num_voxels_per_im*i; % ending index

        im = reshape(new_truth(bind:eind), length_im, width_im);
        cmap = [1 1 1; 0 0 1; 0 1 0; 1 0 1; 1 0 0; 1 1 0];

        if view_output_ims
            % set the figure
            figure(1);
            % plot it using imagesc
            imagesc(im);
            caxis([0 5]);
            colormap(cmap);
            colorbar;
        end

        if save_output_ims
            % save the image as a png file
            fname_png = [out_dir, '/estimate_vol', num2str(v), ...
                         '_sl', num2str(s), '.png'];
            imwrite(im, cmap, fname_png, 'png');
        end
    end
end
